@@ -4,10 +4,12 @@
 #' (international) csv format.
 #' 
 #' @param id of cbs open data table
+#' @param catalog catalog id, can be retrieved with [cbs_get_datasets()]
 #' @param path of data file, defaults to "id/data.csv"
 #' @param ... optional filter statements to select rows of the data,
 #' @param typed Should the data automatically be converted into integer and numeric?
 #' @param verbose show the underlying downloading of the data
+#' @param show_progress show a progress bar while downloading.
 #' @param select optional names of columns to be returned.
 #' @param base_url optionally specify a different server. Useful for
 #' third party data services implementing the same protocol.
@@ -16,14 +18,27 @@
 #' @export
 cbs_download_data <- function( id
                          , path     = file.path(id, "data.csv")
+                         , catalog  = catalog
                          , ...
                          , select   = NULL
                          , typed    = TRUE
                          , verbose  = FALSE
+                         , show_progress = interactive() && !verbose
                          , base_url = getOption("cbsodataR.base_url", BASE_URL)
                          ){
   
   DATASET <- if (typed) "TypedDataSet" else "UntypedDataSet"
+  if (show_progress){
+    rc <- get_row_count(id, catalog = catalog, ...)
+    if (rc == 0){
+      stop("Selection is empty. Please check your filter statements."
+           , call. = FALSE
+      )
+    }
+    pb_value <- 0
+    pb <- utils::txtProgressBar(min = 0, max = rc, style = 3)
+  }
+  base_url <- get_base_url(catalog, base_url)
   url <- whisker.render("{{BASEURL}}/{{BULK}}/{{id}}/{{DATASET}}?$format=json"
                        , list( BASEURL = base_url
                              , BULK    = BULK
@@ -39,7 +54,8 @@ cbs_download_data <- function( id
   # retrieve data
   if (verbose){
     message("Retrieving data from table '", id ,"'")
-  }
+  } 
+  
   url <- URLencode(url)
   res <- get_json(url, verbose = verbose) #jsonlite::fromJSON(url)
   write.table( res$value, 
@@ -54,14 +70,17 @@ cbs_download_data <- function( id
     skip <- gsub(".+skip=(\\w+)", "\\1", url)
     
     if (verbose) {
-      message("Reading...")
-    }
-    
+      message("\nReading...")
+    } else if (show_progress){
+      pb_value <- pb_value + nrow(res$value)
+      utils::setTxtProgressBar(pb, value = pb_value)
+    } 
     res <- get_json(url, verbose = verbose) #jsonlite::fromJSON(url)
     
     if (verbose){
-      message("Writing...")
-    }
+      message("\nWriting...")
+    } 
+    
     
     write.table( res$value
                , file      = data_file
@@ -74,7 +93,14 @@ cbs_download_data <- function( id
     #break
   }
   close(data_file)
-  if (verbose){ message("Done!") }
+  if (verbose){
+    message("\nDone!") 
+  } 
+  
+  if (show_progress){
+    utils::setTxtProgressBar(pb, value = rc)
+    close(pb)
+  } 
 }
 
 #testing
